==> quidproquo-actionprocessor-awslambda-0.0.219.tgz: package/lib/esm/getActionProcessor/core/event/sqs/queue/matchStory.js <==
import { ErrorTypeEnum, EventActionType, actionResult, actionResultError, qpqCoreUtils, } from 'quidproquo-core';
import { matchUrl } from '../../../../../awsLambdaUtils';
export const getQueueConfigSetting = () => {
    const queueQPQConfigSetting = JSON.parse(process.env.queueQPQConfigSetting);
    // TODO: Validate here
    return queueQPQConfigSetting;
};
const getProcessMatchStory = (qpqConfig) => {
    // TODO: Get this out of the qpqconfig like the other event processors
    const queueQPQConfigSetting = getQueueConfigSetting();
    return async ({ qpqEventRecord }) => {
        const queueQueueProcessors = qpqCoreUtils.getQueueQueueProcessors(queueQPQConfigSetting.name, qpqConfig);
        const queueTypes = Object.keys(queueQueueProcessors).sort();
        // Find the most relevant match
        const matchedQueueType = queueTypes
            .map((qt) => ({
            match: matchUrl(qt, qpqEventRecord.message.type),
            queueType: qt,
        }))
            .find((m) => m.match.didMatch);
        if (!matchedQueueType) {
            // If we have event bus subscriptions then we don't want to error if we can't match
            // early exit will just exit gracefully
            if (queueQPQConfigSetting.eventBusSubscriptions.length > 0) {
                return actionResult({});
            }
            return actionResultError(ErrorTypeEnum.NotFound, `queue type not found ${qpqEventRecord.message.type}`);
        }
        const sourceEntry = queueQueueProcessors[matchedQueueType.queueType];
        return actionResult({
            src: sourceEntry.src,
            runtime: sourceEntry.runtime,
            runtimeOptions: matchedQueueType.match.params || {},
            config: matchedQueueType.queueType,
        });
    };
};
export default (qpqConfig) => {
    return {
        [EventActionType.MatchStory]: getProcessMatchStory(qpqConfig),
    };
};

==> quidproquo-actionprocessor-awslambda-0.0.221.tgz: package/lib/esm/getActionProcessor/core/event/sqs/queue/matchStory.js <==
import { ErrorTypeEnum, EventActionType, actionResult, actionResultError, qpqCoreUtils, } from 'quidproquo-core';
import { matchUrl } from '../../../../../awsLambdaUtils';
export const getQueueConfigSetting = () => {
    const queueQPQConfigSetting = JSON.parse(process.env.queueQPQConfigSetting);
    // TODO: Validate here
    return queueQPQConfigSetting;
};
const getProcessMatchStory = (qpqConfig) => {
    // TODO: Get this out of the qpqconfig like the other event processors
    const queueQPQConfigSetting = getQueueConfigSetting();
    const queueQueueProcessors = qpqCoreUtils.getQueueQueueProcessors(queueQPQConfigSetting.name, qpqConfig);
    const queueTypes = Object.keys(queueQueueProcessors).sort();
    return async ({ qpqEventRecord }) => {
        console.log('qpqEventRecord', JSON.stringify(qpqEventRecord, null, 2));
        // Find the most relevant match
        const matchedQueueType = queueTypes
            .map((qt) => ({
            match: matchUrl(qt, qpqEventRecord.message.type),
            queueType: qt,
        }))
            .find((m) => m.match.didMatch);
        if (!matchedQueueType) {
            // If we have event bus subscriptions then we don't want to error if we can't match
            // early exit will just exit gracefully
            if (queueQPQConfigSetting.eventBusSubscriptions.length > 0) {
                return actionResult({});
            }
            return actionResultError(ErrorTypeEnum.NotFound, `queue type not found ${qpqEventRecord.message.type}`);
        }
        const sourceEntry = queueQueueProcessors[matchedQueueType.queueType];
        return actionResult({
            runtime: sourceEntry,
            runtimeOptions: matchedQueueType.match.params || {},
            config: matchedQueueType.queueType,
        });
    };
};
export default (qpqConfig) => {
    return {
        [EventActionType.MatchStory]: getProcessMatchStory(qpqConfig),
    };
};
